@@ -38,22 +38,25 @@ logfolder=""
 lastlogfile=""
 Note=""
 Header=""
-#ChangedNote=0
 StartTime=0
 StartTimeSec=0
 StopTime=0
+MidnightTransitions=0
 ChangesInGraph=0
 run=0
-Mode=0
+QuickMode=0
 version="0"
 build="0"
 user=""
 app_path="./"
 passed_time=0
+DelayStartTime=10
 last_beep=0
 #graphBlocks=0
 OfflineMode="False"
 #OldOfflineMode="False" #restore original state after recording
+DelayStart=0
+interval=0
 
 #arrays, indexes, lenghts
 arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
@@ -62,6 +65,7 @@ arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
 arrDataIndex=0
 arrLogFiles=[]
 arrLogFilesIndex=0
+LogFileSelectedDate=""
 
 ##Explanations of algorithm and array structure
 ## Array arrData
