@@ -33,6 +33,7 @@ from Ui_StartWindow import *
 from Ui_RecordWindow import *
 from Ui_ViewWindow import *
 from Ui_ConfigWindow import *
+from Ui_DateWindow import *
 
 
 
@@ -42,7 +43,7 @@ from Ui_ConfigWindow import *
 # Main function
 ###########################################################################
 def main():
-    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow
+    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow
     global config
     global RecordWindowGraph
    
@@ -74,6 +75,7 @@ def main():
         data.trigger=30  
         config.set('main', 'Ysize', str(data.Ysize))      
         config.set('main', 'Yscale', str(data.Yscale))      
+#        config.set('main', 'trigger', str(data.trigger))   
         print "changed default parameters for Yscale and Ysize"
     
     
@@ -87,8 +89,9 @@ def main():
     
     # Create subwindows
     RecordWindow = frmRecordWindow(StartWindow)
-    ViewWindow = frmViewWindow(StartWindow)
     ConfigWindow = frmConfigWindow(StartWindow)
+    ViewWindow = frmViewWindow(StartWindow)
+    DateWindow = frmDateWindow(ViewWindow)
     
     # Hide SubWindows at first
     RecordWindow.hide()
@@ -143,9 +146,9 @@ def TimerLoop():
 ###########################################################################
 # Starte the measurement
 ###########################################################################
-def StartMeasurement():
+def DelayStartMeasurement():
     global app
-    #init value
+    #init values
     data.sample_index=0
     data.values_total=0
     data.arrDataIndex=0
@@ -154,49 +157,83 @@ def StartMeasurement():
     for i in range(0,  len(data.arrData)): #clear data of old records
         for j in range(0,  5): data.arrData[j][i]=0
     
-    if(data.Mode==0):
-        interval=data.sampling #normal
+    if(data.QuickMode==0):
+        data.interval=data.sampling #normal
         if(data.OfflineMode=="True"): #change to offline mode
             cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
             os.popen(cmd)
-        data.Xscale=1 #default zoom level
+        data.Xscale=1 #set to default zoom level
     else:  
-        interval=10 #Fast mode for testing
-        data.Xscale=0 #max zoom level
+        data.interval=10 #Fast mode for testing
+        data.Xscale=0 #set to max zoom level
     
-    data.run=1
-    app.timer_GetData = QtCore.QTimer()
-    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
-    app.timer_GetData.start(interval) 
+    data.run=1 #change to delayed start
+#    app.timer_GetData = QtCore.QTimer()
+#    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
+#    app.timer_GetData.start(interval) 
+
+    app.timer_Delay = QtCore.QTimer()
+    QtCore.QObject.connect(app.timer_Delay, QtCore.SIGNAL("timeout()"), StartDelayTimerLoop)     
+    if(data.QuickMode==1 or data.DelayStartTime==0): #quick mode
+        data.DelayStart=0
+        app.timer_Delay.start(1) #milliseconds  (make it very quick)
+    else:
+        data.DelayStart=data.DelayStartTime
+        app.timer_Delay.start(1000) #milliseconds         
    
     data.ChangesInGraph=1 #Make sure it only gets refreshed once    
     RecordWindowGraph.update() #show RecordWindowGraph        
-    RecordWindow.UpdateScreen()    
+    RecordWindow.UpdateScreen()     #needed?
+    
     
-    StartLogfile(interval)
         
     
-    print "Start timers (Interval:", interval ,"ms)..."
-    print "Sampling interval:", interval, "ms"
+    print "Start timers (Interval:", data.interval ,"ms)..."
+    print "Sampling interval:", data.interval, "ms"
     print "sample_smoothing:", data.sample_smoothing, "x"
     print "value_smoothing:", data.value_smoothing, "x"
-    print "=> log interval:", interval*data.value_smoothing, "ms"
+    print "=> log interval:", data.interval*data.value_smoothing, "ms"
     print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
     
 
+
+
     
     
+def StartDelayTimerLoop():
+#    print "StartDelayTimerLoop"
+    data.DelayStart=data.DelayStart-1
+    if(data.DelayStart<=0):  #delay over
+        app.timer_Delay.stop()
+        
+        data.run=2 #change to recording
+        
+        app.timer_GetData = QtCore.QTimer()
+        QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
+        app.timer_GetData.start(data.interval) 
+        
+        StartLogfile(data.interval)
+        RecordWindow.UpdateScreenStart() 
+        
+    else:
+        RecordWindow.DelayStart()
+    
+
+
 
 
 def StopMeasurement():
     global app
-    data.run=0
 #    print "Stop timers..."
-    app.timer_GetData.stop()
+    if(data.run==1): #in delayed start
+        app.timer_Delay.stop()
+    elif(data.run==2): #in recording
+        app.timer_GetData.stop()
+        StopLogfile() 
+   
     data.run=0
-    StopLogfile()       
     
-    if(data.Mode==0): #normal mode
+    if(data.QuickMode==0): #normal mode
         if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
             cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
             os.popen(cmd)
@@ -284,11 +321,11 @@ class frmStartWindow(QMainWindow):
         self.ui.textBrowser.setHtml(txt)
         
         if(data.app_path!="./"): #only needed if not started in app path
-            self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"SleepAnalyser.png"))
-            self.ui.bQuick.setIcon(QIcon(data.app_path+"krec.png"))
-            self.ui.bCollecting.setIcon(QIcon(data.app_path+"krec.png"))
-            self.ui.bLog.setIcon(QIcon(data.app_path+"zoom.png"))
-            self.ui.bConfig.setIcon(QIcon(data.app_path+"configure.png"))
+            self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
+            self.ui.bQuick.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
+            self.ui.bCollecting.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
+            self.ui.bLog.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
+            self.ui.bConfig.setIcon(QIcon(data.app_path+"img/"+"configure.png"))
 
 
 
@@ -296,7 +333,7 @@ class frmStartWindow(QMainWindow):
     # Show the collectring window (hera the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementNormal(self):
-        data.Mode=0 #run in normal mode
+        data.QuickMode=0 #run in normal mode
         data.test=0 #show axis lables        
         self.StartMeasurement()
         
@@ -305,7 +342,7 @@ class frmStartWindow(QMainWindow):
     # Show the collectring window (hera the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementQuick(self):
-        data.Mode=1 #run in quick mode (for testing only)
+        data.QuickMode=1 #run in quick mode (for testing only)
         data.Xscale=0 #default zoom level
         data.test=1 #hide axis lables
         self.StartMeasurement()
@@ -316,8 +353,8 @@ class frmStartWindow(QMainWindow):
         RecordWindow.show()
 #        StartWindow.hide()
         RecordWindowGraph = RecordWindowCanvas(RecordWindow)
-        StartMeasurement()
-        RecordWindow.UpdateScreenStart()
+        DelayStartMeasurement()
+        RecordWindow.UpdateScreenDelayStart()
         RecordWindowGraph.show()
         
         
@@ -385,7 +422,7 @@ class frmStartWindow(QMainWindow):
         except:
             print "Version file not found"
         self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
+#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
 
     def closeEvent(self, event):
         global config
@@ -426,24 +463,69 @@ class frmRecordWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
         QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
+        QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         
         if(data.app_path!="./"): #only needed if not started in app path
-            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
-            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
-            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
-            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
+            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"img/"+"zoom-in.png"))
+            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"img/"+"zoom-out.png"))
+            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
+            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
+            self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
             
 
+    def UpdateScreenDelayStart(self):
+        self.ui.lblStarttime.setText("(Delayed "+str(data.DelayStart)+" sec)")
+#        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
+#        self.ui.lblStarttime.setText("")
+        self.ui.lblSamples_Taken.setText("")
+        self.ui.lblElapsedTime.setText("")
+        self.ui.lblNote.setText("")
+        self.ui.lblLogfile.setText("")
+#        self.ui.lblYscale.setText(str(data.Yscale))
+#        self.ui.lblTrigger.setText(str(data.trigger))
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
+        self.ui.bStop.setText("Stop recording")
+
+        self.UpdateScreen()
+        
+        
+        
+    def DelayStart(self):
+        self.ui.lblStarttime.setText("(Delayed "+str(data.DelayStart)+" sec)")
+        
+
+
+    def UpdateScreenStart(self):
+#        print "UpdateScreenStart"
+        self.ui.lblLogfile.setText(str(data.logfilename))
+        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
+        self.ui.lblStarttime.setText(t)
+#        self.ui.lblSamples_Taken.setText("0")
+        self.ui.lblElapsedTime.setText("")
+#        self.ui.lblNote.setText("")
+#        self.ui.lblYscale.setText(str(data.Yscale))
+#        self.ui.lblTrigger.setText(str(data.trigger))
+#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+#        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
+#        self.ui.bStop.setText("Stop recording")
+
+        self.UpdateScreen()
+        
+        
+        
     def UpdateScreen(self):
         if(data.demo==0):
             self.ui.lblSamples_Taken.setText(str(data.values_total))
         else:
             self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Demo Mode)")
 
-        t=time.mktime(time.localtime())
-        time_difference=t-data.StartTimeSec
-        t=strftime("%H:%M:%S", time.gmtime(time_difference))
-        self.ui.lblElapsedTime.setText(t)
+#        print "UpdateScreen",  data.run
+        if(data.run==2): #recording
+            t=time.mktime(time.localtime())
+            time_difference=t-data.StartTimeSec
+            t=strftime("%H:%M:%S", time.gmtime(time_difference))
+            self.ui.lblElapsedTime.setText(t)
 #        self.ui.lblTrigger.setText(str(data.trigger))
         
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -457,41 +539,34 @@ class frmRecordWindow(QMainWindow):
         else: self.ui.bLowerTrigger.setEnabled(True)
             
 
-    def UpdateScreenStart(self):
-        self.ui.lblLogfile.setText(str(data.logfilename))
-        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
-        self.ui.lblStarttime.setText(t)
-        self.ui.lblSamples_Taken.setText("0")
-        self.ui.lblElapsedTime.setText("00:00:00")
-        self.ui.lblNote.setText("")
-#        self.ui.lblYscale.setText(str(data.Yscale))
-#        self.ui.lblTrigger.setText(str(data.trigger))
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
-        self.ui.bStop.setIcon(QIcon(data.app_path+"krec2.png"))
-        self.ui.bStop.setText("Stop recording")
 
-        self.UpdateScreen()
         
         
     def UpdateScreenStop(self):
+#        self.ui.lblStarttime.setText("(Stopped)")
         self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
-        self.ui.bStop.setIcon(QIcon(data.app_path+"krec.png"))
+        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
         self.ui.bStop.setText("Start recording")
         
         
+        
+        
     def ToggleMeasurement(self):
         global app
         if(data.run==0): #not running
-            StartMeasurement()
-            self.UpdateScreenStart()
+            DelayStartMeasurement()
+            self.UpdateScreenDelayStart()
+        elif(data.run==1): # in delayed start
+            StopMeasurement()
+            self.UpdateScreenStop()
+            data.test=0 # reset test mode if was active
         else: #running
             StopMeasurement()
-            self.askdumprecord()  
+            self.AskKeepRecord()  
             self.UpdateScreenStop()
             data.test=0 # reset test mode if was active
         
-        
-        
+                
     def ZoomIn(self):
         Zoom(+1)
 #        self.ui.bZoomOut.setEnabled(True)
@@ -528,14 +603,17 @@ class frmRecordWindow(QMainWindow):
 
     def closeEvent(self, event):
         #in case measurement is still running (user did not click on "stop")
-        if(data.run==1): 
+        if(data.run==1): #delayed start
+            StopMeasurement()     
+        if(data.run==2): #running
             StopMeasurement()
-            self.askdumprecord()            
+            self.AskKeepRecord()     
+#        ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
         StartWindow.show()
         self.close() 
 
 
-    def askdumprecord(self):
+    def AskKeepRecord(self):
     #check if user wants to keep this record
         reply = QtGui.QMessageBox.question(self, 'Keep this Record?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.No:
@@ -546,15 +624,18 @@ class frmRecordWindow(QMainWindow):
 #            print "lastlogfile:",  data.lastlogfile
             config.set('main', 'lastlogfile', str(data.lastlogfile))   
             
-            self.EditNote() #request adding a note
+#            self.EditNote() #request adding a note
+            ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
 
 
     def EditNote(self):
         r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  data.Note)
         if(r[1]==True): #OK pressed
+#            n=unicode(r[0], 'utf-8')
             data.Note=str(r[0])
             self.ui.lblNote.setText(str(data.Note))
-            ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
+            if(data.run==0): ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
+
 
 
 
@@ -591,6 +672,7 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
         QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
+        QtCore.QObject.connect(self.ui.bOpenDate, QtCore.SIGNAL("clicked()"), self.OpenDate)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
         QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
@@ -599,16 +681,18 @@ class frmViewWindow(QMainWindow):
         self.ui.bRight.hide() #not yet used
         
         if(data.app_path!="./"): #only needed if not started in app path
-            self.ui.bLast.setIcon(QIcon(data.app_path+"arrow-left-double.png"))
-            self.ui.bNext.setIcon(QIcon(data.app_path+"arrow-right-double.png"))
-            self.ui.bDelete.setIcon(QIcon(data.app_path+"edittrash.png"))
-            self.ui.bOpen.setIcon(QIcon(data.app_path+"document-open-folder.png"))
-            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
-            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
-            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
-            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
-            self.ui.bLeft.setIcon(QIcon(data.app_path+"go-previous.png"))
-            self.ui.bRight.setIcon(QIcon(data.app_path+"go-next.png"))
+            self.ui.bLast.setIcon(QIcon(data.app_path+"img/"+"arrow-left-double.png"))
+            self.ui.bNext.setIcon(QIcon(data.app_path+"img/"+"arrow-right-double.png"))
+            self.ui.bDelete.setIcon(QIcon(data.app_path+"img/"+"edittrash.png"))
+            self.ui.bOpen.setIcon(QIcon(data.app_path+"img/"+"document-open-folder.png"))
+            self.ui.bOpenDate.setIcon(QIcon(data.app_path+"img/"+"date.png"))
+            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"img/"+"zoom-in.png"))
+            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"img/"+"zoom-out.png"))
+            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
+            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
+            self.ui.bLeft.setIcon(QIcon(data.app_path+"img/"+"go-previous.png"))
+            self.ui.bRight.setIcon(QIcon(data.app_path+"img/"+"go-next.png"))
+            self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
             
 #        self.ui.lblYscale.setText(str(data.Yscale))
 
@@ -786,10 +870,14 @@ class frmViewWindow(QMainWindow):
 #        x=tmp2[l-1]
 #        return x
         return tmp
+        
+    def OpenDate(self):
+        DateWindow.show()
+        DateWindow.DateChanged()
 
 
     def closeEvent(self, event):
-        config.set('main', 'trigger', str(data.trigger))      
+#        config.set('main', 'trigger', str(data.trigger))      
         ViewWindow.close()
         StartWindow.show()
 
@@ -826,9 +914,10 @@ class frmConfigWindow(QMainWindow):
         
         self.ui = Ui_ConfigWindow()
         self.ui.setupUi(self)
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
               
         QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
+        QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.SliderMoved)
         
         
 
@@ -836,6 +925,8 @@ class frmConfigWindow(QMainWindow):
         if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
         else: self.ui.cOfflineMode.setChecked(False)        
         self.ui.lblUserName.setText(str(data.user))
+        self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
+        self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
 
 
     def closeEvent(self, event):        
@@ -845,6 +936,8 @@ class frmConfigWindow(QMainWindow):
             data.OfflineMode="False"
         config.set('main', 'OfflineMode', str(data.OfflineMode))   
         config.set('main', 'user', str(data.user))      
+#        data.DelayStartTime=int(self.ui.SliderStartDelay.value())
+        config.set('main', 'DelayStartTime', str(data.DelayStartTime))      
         
         ConfigWindow.close()
         StartWindow.show()
@@ -853,6 +946,71 @@ class frmConfigWindow(QMainWindow):
     def EditUserName(self):
         EditUserName()
         self.ui.lblUserName.setText(str(data.user))
+        
+        
+    def SliderMoved(self):
+        data.DelayStartTime=self.ui.SlrDelayStart.value()
+        self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
+
+
+
+
+
+
+
+
+###########################################################################
+# Class for Date Window
+###########################################################################
+class frmDateWindow(QMainWindow):
+    def __init__(self, parent=None):
+#        QMainWindow.__init__(self, parent)
+        # Notice that you must give a parent window as parameter to the constuctor
+        QMainWindow.__init__(self, parent)
+        # Also set the Stacked Window parameter for every subwindow in the stack
+        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        
+        self.ui = Ui_DateWindow()
+        self.ui.setupUi(self)
+#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+#        
+        if(data.app_path!="./"): #only needed if not started in app path
+            self.ui.bOpen.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
+
+        QtCore.QObject.connect(self.ui.cal, QtCore.SIGNAL('selectionChanged()'), self.DateChanged)
+        QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
+        
+        self.ui.cal.showToday()
+
+
+    def DateChanged(self):
+        date = self.ui.cal.selectedDate()
+        date=str(date.toPyDate())
+
+        print "Load list of all csv files in folder:",  data.logfolder + " with date " + date
+        output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *"+date+"*.csv").read() # run ls and make the output look like a file I can read
+        arrLogFiles=output.split("\n")
+        arrLogFiles.pop()
+
+        amount=len(arrLogFiles)
+#        for i in range(amount): print arrLogFiles[i]
+        
+        self.ui.lblResult.setText("Found "+str(amount)+" Records for this date.")
+        if(amount>0): 
+            self.ui.bOpen.setEnabled(True)
+            data.LogFileSelectedDate=arrLogFiles[0] #select first file of that date for opening
+        else: self.ui.bOpen.setEnabled(False)
+
+
+    def OpenRecord(self):
+        data.logfilename=data.LogFileSelectedDate
+        print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+        DateWindow.hide()
+        ViewWindow.ShowLogFile()
+
+
+    def closeEvent(self, event):        
+        pass
 
 
 
